/*
 * Copyright (C) 2016-2019 Rinigus https://github.com/rinigus
 *
 * This file is part of OSM Scout Server.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "."
import "platform"

DialogPL {
    id: dialog
    title: qsTr("Automatic activation")

    Column {
        id: column

        width: parent.width
        spacing: styler.themePaddingLarge

        ListItemLabel {
            text: qsTr("OSM Scout Server can be activated automatically when the clients access it. " +
                       "When started automatically, it will be stopped if idle after given period of time.")
        }

        ListItemLabel {
            text: qsTr("Do you want to enable automatic activation?")
            visible: settings.hasBackendSystemD
        }

        TextSwitchPL {
            id: systemdEnable
            text: qsTr("Automatic activation")
            visible: settings.hasBackendSystemD
            Component.onCompleted: {
                checked = systemd_service.enabled
            }
        }

        ListItemLabel {
            font.pixelSize: styler.themeFontSizeSmall
            text: qsTr("It is recommended to enable automatic activation to simplify the access to the server.")
        }

        ListItemLabel {
            font.pixelSize: styler.themeFontSizeSmall
            text: qsTr("Note that when automatically activated, the server runs without any user interface. " +
                       "Automatic activation and the corresponding idle timeout can be later configured in Settings.")
            visible: settings.hasBackendSystemD
        }

        ListItemLabel {
            font.pixelSize: styler.themeFontSizeSmall
            text: qsTr("For installations without <i>systemd</i>, you can run the server as one of the automatically started programs on login. " +
                       "See <a href='https://rinigus.github.io/osmscout-server/'>User's Guide</a> for details on how to start the server correctly in this case.")
            visible: !settings.hasBackendSystemD
        }

        ListItemLabel {
            font.pixelSize: styler.themeFontSizeSmall
            text: qsTr("For technical details, created files, and how to remove them if needed, see corresponding section " +
                       "of the <a href='https://rinigus.github.io/osmscout-server/en/#implementation-of-automatic-activation'>User's Guide</a>.")
        }
    }

    onAccepted: {
        if (settings.hasBackendSystemD)
            systemd_service.enabled = systemdEnable.checked
    }
}
